@@ -111,10 +111,6 @@
         return this.frame.map_to_screen(x, x_units, y, y_units, this.canvas, x_name, y_name);
       };
 
-      PlotView.prototype.map_from_screen = function(sx, sy, units) {
-        return this.frame.map_from_screen(sx, sy, units, this.canvas, name);
-      };
-
       PlotView.prototype.update_range = function(range_info) {
         var name, rng, _ref1, _ref2;
         if (range_info == null) {
@@ -223,11 +219,16 @@
       };
 
       PlotView.prototype.render = function(force_canvas) {
-        var canvas, ctx, frame, frame_box, k, sx, sy, th, title, v, _ref1;
+        var canvas, ctx, frame, frame_box, height, k, sx, sy, th, title, trigger, v, width, _ref1;
         if (force_canvas == null) {
           force_canvas = false;
         }
         logger.trace("Plot.render(force_canvas=" + force_canvas + ")");
+        width = this.mget("plot_width");
+        height = this.mget("plot_height");
+        if (this.canvas.get("canvas_width") !== width || this.canvas.get("canvas_height") !== height) {
+          this.canvas._set_dims([width, height], trigger = false);
+        }
         PlotView.__super__.render.call(this);
         this.canvas_view.render(force_canvas);
         if (this.tm_view != null) {
@@ -251,8 +252,8 @@
             this.model.title_panel.set('height', th);
           }
         }
-        this.model.get('frame').set('width', canvas.get('width'));
-        this.model.get('frame').set('height', canvas.get('height'));
+        this.model.get('frame').set('width', canvas.get('width') - 1);
+        this.model.get('frame').set('height', canvas.get('height') - 1);
         this.canvas.solver.update_variables(false);
         this.model.get('frame')._update_mappers();
         if (this.initial_range_info == null) {
