@@ -1,8 +1,10 @@
 import pandas as pd
+import numpy as np
 from collections import OrderedDict
 
 from bokeh.sampledata.olympics2014 import data
 from bokeh.charts import Donut
+from bokeh.plotting import show, output_file
 
 # we throw the data into a pandas df
 df = pd.io.json.json_normalize(data['data'])
@@ -17,13 +19,15 @@ silver = df['medals.silver'].astype(float).values
 bronze = df['medals.bronze'].astype(float).values
 
 # later, we build a dict containing the grouped data
-medals = OrderedDict(bronze=bronze, silver=silver, gold=gold)
-
-# any of the following commented are valid Bar inputs
-#medals = pd.DataFrame(medals).T.values
-#medals = list(medals.values())
-#medas = pd.DataFrame(medals)
+medals = OrderedDict()
+medals['bronze'] = bronze
+medals['silver'] = silver
+medals['gold'] = gold
 
+# any of the following commented are valid Donut inputs
+# medals = list(medals.values())
+# medals = np.array(list(medals.values()))
+# medals = pd.DataFrame(medals)
+output_file("donut.html")
 donut = Donut(medals, countries, filename="donut.html")
-donut.title("Medals Donut").xlabel("countries").ylabel("medals")
-donut.legend(True).width(800).height(800).show()
+show(donut) # or donut.show()
